package
Version:
v0.0.0-...-688c5a7
Opens a new window with list of versions in this module.
Published: Oct 3, 2024
License: MIT
Opens a new window with license information.
Imports: 11
Opens a new window with list of imports.
Imported by: 0
Opens a new window with list of known importers.
Documentation
¶
type JSONPayload struct {
ReviewId int `json:"review_id"`
ReviewUrl string `json:"review_url"`
ReviewCompleted bool `json:"review_completed"`
Highlights []readwiseHighlight `json:"highlights"`
}
Source Files
¶
Click to show internal directories.
Click to hide internal directories.